@@ -1,24 +1,15 @@
 # -*- coding: UTF-8 -*-
-'''
-@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫，微信：CoderWanFeng
-@读者群     ：http://www.python4office.cn/wechat-group/
-@学习网站      ：https://www.python-office.com
-@代码日期    ：2023/8/22 23:28
-'''
 
 import pofile
-import search4file
+
 
 # todo：输入文件路径
-# @except_dec()
-from office.lib.decorator_utils.instruction_url import instruction
 
 
-# @instruction
 def replace4filename(path: str, del_content, replace_content='', dir_rename: bool = True,
                      file_rename: bool = True, suffix=None):
     """
-    批量修改文件/文件夹名称
+    批量重命名 1：批量修改文件/文件夹名称
     :param path: 必填，需要修改文件夹/文件名称的根目录，注意：该根目录名称不会被修改
     :param del_content: 必填，需要替换/删除的内容
     :param replace_content: 选填，替换后的内容，不填则实现删除效果
@@ -30,66 +21,115 @@ def replace4filename(path: str, del_content, replace_content='', dir_rename: boo
     pofile.replace4filename(path, del_content, replace_content, dir_rename, file_rename, suffix)
 
 
-# todo：输入文件路径
-# @except_dec()
-# @instruction
-def search_by_content(search_path: str, content: str):
+# author：https://github.com/CoderWanFeng/python-office/pull/72
+def file_name_insert_content(file_path: str, insert_position: int, insert_content: str):
     """
-    通过内容搜索文件
+    批量重命名 2：在文件名中间插入字符
     Args:
-        search_path: 需要搜索的目录
-        content: 搜索的内容
+        file_path:
+        insert_position:
+        insert_content:
 
     Returns:
 
     """
-    search4file.search_by_content(search_path=search_path, search_content=content)
-
-
-# author：https://github.com/CoderWanFeng/python-office/pull/72
-# @except_dec()
-# @instruction
-def file_name_insert_content(file_path: str, insert_position: int, insert_content: str):
     pofile.file_name_insert_content(file_path, insert_position, insert_content)
 
 
 # author：https://github.com/CoderWanFeng/python-office/pull/72
-# @except_dec()
-# @instruction
 def file_name_add_prefix(file_path: str, prefix_content: str):
+    """
+    批量重命名 3：给文件名给增加前缀
+    Args:
+        file_path:
+        prefix_content:
+
+    Returns:
+
+    """
     pofile.file_name_add_prefix(file_path, prefix_content)
 
 
 # author：https://github.com/CoderWanFeng/python-office/pull/72
-# @except_dec()
-# @instruction
 def file_name_add_postfix(file_path, postfix_content):
+    """
+    批量重命名 4：给文件名给增加后缀
+    Args:
+        file_path:
+        postfix_content:
+
+    Returns:
+
+    """
     pofile.file_name_add_postfix(file_path, postfix_content)
 
 
-# author：https://github.com/CoderWanFeng/python-office/pull/74
-# @except_dec()
-# @instruction
-def search_specify_type_file(file_path, file_type):
-    pofile.search_specify_type_file(file_path, file_type)
-
-
-# @except_dec()
-# @instruction
 def output_file_list_to_excel(dir_path):
+    """
+    整理当前文件夹下的文件名，到一个Excel里
+    Args:
+        dir_path:
+
+    Returns:
+
+    """
     pofile.output_file_list_to_excel(dir_path)
 
 
-# @instruction
 def add_line_by_type(add_line_dict: dict, file_path, file_type='.py', output_path=r'add_line'):
+    """
+    #TODO：忘记功能了，待测试
+    Args:
+        add_line_dict:
+        file_path:
+        file_type:
+        output_path:
+
+    Returns:
+
+    """
     pofile.add_line_by_type(add_line_dict, file_path, file_type, output_path)
 
 
-# @instruction
+# author：https://github.com/CoderWanFeng/python-office/pull/74
+def search_specify_type_file(file_path, file_type):
+    """
+    当前路径下，搜索指定类型的文件
+    Args:
+        file_path:
+        file_type:
+
+    Returns:
+
+    """
+    pofile.search_specify_type_file(file_path, file_type)
+
+
 def group_by_name(path, output_path=None, del_old_file=None):
+    """
+    #TODO：忘记功能了，待测试
+    Args:
+        path:
+        output_path:
+        del_old_file:
+
+    Returns:
+
+    """
     pofile.group_by_name(path, output_path, del_old_file)
 
 
-# @instruction
 def get_files(path: str, name: str = '', suffix: str = None, sub: bool = False, level: int = 0) -> list:
+    """
+    搜索当前路径下，所有指定类型的文件，并以列表的形式返回
+    Args:
+        path:
+        name:
+        suffix:
+        sub:
+        level:
+
+    Returns:
+
+    """
     return pofile.get_files(path, name, suffix, sub, level)
