@@ -1,11 +1,4 @@
 # -*- coding: UTF-8 -*-
-'''
-@作者 ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫
-@微信 ：CoderWanFeng : https://mp.weixin.qq.com/s/8x7c9qiAneTsDJq9JnWLgA
-@个人网站 ：www.python-office.com
-@Date    ：2023/6/1 22:52 
-@Description     ：
-'''
 
 from decimal import Decimal
 RATE_LINE = 10000 * 2
