@@ -1,24 +1,33 @@
-# from office.core.VideoType import MainVideo
-# mainVideo = MainVideo()
 import povideo
 
 # 从视频里提取音频
-from office.lib.decorator_utils.instruction_url import instruction
 
 
-# @instruction
+
+
 def video2mp3(path, mp3_name=None, output_path=r'./'):
-    povideo.video2mp3(path, mp3_name, output_path)
+    """
+    将视频文件转换为mp3音频文件。
 
+    参数:
+    - path (str): 视频文件的路径。
+    - mp3_name (str, optional): 输出mp3文件的名称。如果未提供，默认为原视频文件名。
+    - output_path (str, optional): 输出mp3文件的路径。默认为当前目录('./')。
+
+    返回:
+    无返回值，但会在指定输出路径下生成mp3文件。
+    """
+    # 调用povideo模块中的video2mp3方法进行视频到mp3的转换
+    povideo.video2mp3(path, mp3_name, output_path)
 
 # 从音频里，提取文字
 # 本地语音文件不能大于5MB
-# @instruction
+
 def audio2txt(audio_path, appid, secret_id, secret_key):
     povideo.audio2txt(audio_path, appid, secret_id, secret_key)
 
 
-# @instruction
+
 def mark2video(video_path, output_path=r'./', output_name=r'mark2video.mp4', mark_str: str = "www.python-office.com",
                font_size=28,
                font_type='Arial', font_color='white'):
@@ -35,7 +44,8 @@ def mark2video(video_path, output_path=r'./', output_name=r'mark2video.mp4', mar
     """
     povideo.mark2video(video_path, output_path, output_name, mark_str, font_size, font_type, font_color)
 
-# @instruction
+
+
 def txt2mp3(content='程序员晚枫', file=None, mp3=r'./程序员晚枫.mp3', speak=True):
     """
     文本转语音
